==> fetch.php?media=oais%3Adocuteam_packer-2.2.0.zip: ch/docuteam/darc/util/KeyAndValue.java <==
/**
 *	Copyright (C) 2011-2015 Docuteam GmbH
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 3
 *	as published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.docuteam.darc.util;


public class KeyAndValue
{
	static private final String		KeyStartString = "${";
	static private final String		KeyEndString = "}";

	private String					originalString;
	private String					key;
	private String					value;



	static public boolean containsKey(String string)
	{
		if ((string == null)
		|| !(string.contains(KeyStartString) && string.contains(KeyEndString)))		return false;

		int keyStartIndex = string.indexOf(KeyStartString);
		if (keyStartIndex == -1)													return false;
		if (string.indexOf(KeyEndString, keyStartIndex) == -1)						return false;

		return true;
	}


	public KeyAndValue(String string)
	{
		this.originalString = string;
		this.value = string;

		if (!containsKey(string))		return;

		int keyStartIndex = string.indexOf(KeyStartString);
		int keyEndIndex = string.indexOf(KeyEndString, keyStartIndex);

		this.key = string.substring(keyStartIndex + KeyStartString.length(), keyEndIndex);
		this.value = string.replace(string.substring(keyStartIndex, keyEndIndex + KeyEndString.length()), "");
	}


	public String getOriginalString()
	{
		return this.originalString;
	}

	public String getKey()
	{
		return this.key;
	}

	public String getValue()
	{
		return this.value;
	}


	@Override
	public String toString()
	{
		return this.value;
	}

}

==> fetch.php?media=oais%3Adocuteam_packer-2.5.0.zip: ch/docuteam/darc/util/KeyAndValue.java <==
/**
 *	Copyright (C) 2011-2016 Docuteam GmbH
 *
 *	This program is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 3
 *	as published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.docuteam.darc.util;

public class KeyAndValue {
	static private final String KeyStartString = "${";
	static private final String KeyEndString = "}";

	private String originalString;
	private String key;
	private String value;

	static public boolean containsKey(String string) {
		if ((string == null) || !(string.contains(KeyStartString) && string.contains(KeyEndString)))
			return false;

		int keyStartIndex = string.indexOf(KeyStartString);
		if (keyStartIndex == -1)
			return false;
		if (string.indexOf(KeyEndString, keyStartIndex) == -1)
			return false;

		return true;
	}

	public KeyAndValue(String string) {
		this.originalString = string;
		this.value = string;

		if (!containsKey(string))
			return;

		int keyStartIndex = string.indexOf(KeyStartString);
		int keyEndIndex = string.indexOf(KeyEndString, keyStartIndex);

		this.key = string.substring(keyStartIndex + KeyStartString.length(), keyEndIndex);
		this.value = string.replace(string.substring(keyStartIndex, keyEndIndex + KeyEndString.length()), "");
	}

	public String getOriginalString() {
		return this.originalString;
	}

	public String getKey() {
		return this.key;
	}

	public String getValue() {
		return this.value;
	}

	@Override
	public String toString() {
		return this.value;
	}

}
